# FuncNodes YOLO

## Overview

`funcnodes-yolo` is an extension of the [FuncNodes](https://github.com/linkdlab/funcnodes) framework that provides nodes to use the [Yolo models from ultralytics](https://github.com/ultralytics/ultralytics) package

## Installation

Install the package using:

```bash
pip install funcnodes-yolo
```

## Getting Started

To begin using `funcnodes-yolo`, you will need to have the core `FuncNodes` framework installed and set up. Please refer to the [FuncNodes](https://github.com/linkdlab/funcnodes) documentation for details.

## Contribution

You are welcome to contribute to this project by submitting pull requests, adding new nodes, fixing bugs, or enhancing the documentation.

## License

This project is licensed under the AGPL-3.0 License.

## Contact

For any questions or issues, please open an issue on the GitHub repository.
